@@ -152,7 +152,8 @@ def get_clusterer(history_path, errors_path=''):
                                        n_init=settings['n_init'],
                                        n_jobs=-1)
 
-    clusterer.fit(numpy.array(data))
+    if not settings.get('skip'):
+        clusterer.fit(numpy.array(data))
 
     cherrypy.log('Done')
 
@@ -208,7 +209,7 @@ def get_clustered_group(workflow, clusterer, session=None):
     group = predictions.get(workflow)
 
     if group is not None:
-        for wkf, cluster in predictions.iteritems():
+        for wkf, cluster in predictions.items():
             if cluster == group and wkf != workflow:
                 output.append(wkf)
 
