@@ -1,7 +1,8 @@
 var allHeader = "All Steps (use this or fill all others)";
 
 function normalize (s) {
-    return s.replace(/^_+/, "");
+    return s.replace(/__\d*$/, ""). // Remove the counter for separating radios
+        replace(/^_+/, "");         // Remove leading "_". Don't remember what those are from.
 }
 
 function printSiteLists (method, params) {
@@ -33,7 +34,7 @@ function printSiteLists (method, params) {
                     $(siteListDiv.appendChild(document.createElement("input"))).
                         attr("type", "checkbox").attr("name", "sites").
                         attr("value", site.site).
-                        attr("checked", (method == "Ban" && bad) || (method != "Ban" && run));
+                        attr("checked", (method == "Ban" && bad) || (method != "Ban" && run && !bad));
                     siteListDiv.appendChild(document.createTextNode(site.site));
                 });
                 siteList.appendChild(document.createElement("div")).className = "clear";
@@ -107,6 +108,8 @@ function makeTable (option, params) {
     else
         addParamTable().style.margin = "15px 0px 15px 0px";
 
+    counter = 0;
+
     $(".paramtable").each(function () {
         var paramtable = this;
         option.opts.forEach(function (opt) {
@@ -117,7 +120,7 @@ function makeTable (option, params) {
                 optDiv.appendChild(document.createTextNode("    " + value + "  "));
                 var radio = optDiv.appendChild(document.createElement("input"));
                 radio.type = "radio";
-                radio.name = opt.name;
+                radio.name = opt.name + "__" + counter;
                 radio.value = value;
                 radio.ondblclick = function() {
                     this.checked = false;
@@ -133,6 +136,9 @@ function makeTable (option, params) {
             input.type = "text";
             input.name = text;
         });
+
+        // Increment counter so that radio buttons are split
+        counter++;
     });
 };
 
@@ -239,13 +245,16 @@ function addOptions (form, params) {
         }
     ].forEach(function (option) {
 
-        $(form.appendChild(document.createElement("input"))).
+        var optspan = form.appendChild(document.createElement("span"));
+        $(optspan).attr("id", "opt" + option.action);
+
+        $(optspan.appendChild(document.createElement("input"))).
             attr("type", "radio").attr("name", "action").attr("value", option.action).
             click(function () {
                 makeTable(option, params)
             });
 
-        form.appendChild(document.createTextNode(option.description));
+        optspan.appendChild(document.createTextNode(option.description));
 
     });
 
@@ -260,7 +269,7 @@ function paramsOfDiv (sel) {
     return output;
 }
 
-function buildSubmit (workflow, sitesToRun) {
+function buildSubmit (workflow, sitesToRun, allsites) {
     var action = $("form input[name=action]:checked").val();
     var siteMethod = $("#sitemethods input:radio:checked").val();
 
@@ -278,8 +287,15 @@ function buildSubmit (workflow, sitesToRun) {
                     var stepName = sel.find(".taskparamhead a").html();
                     var stepParams = paramsOfDiv(this);
                     stepParams["sites"] = function () {
-                        if (siteMethod == "Auto")
-                            return sitesToRun[stepName];
+                        if (siteMethod == "Auto") {
+                            // Filter out drained
+                            var siteMap = {};
+                            allsites.forEach(function (site) {
+                                    siteMap[site.site] = site.drain;
+                                });
+
+                            return sitesToRun[stepName].filter(function (site) {return siteMap[site] == 'enabled';});
+                        }
                         if (siteMethod == "Manual")
                             return sel.find(".sitecheck input:checked").map(function (i, ele) { return ele.value }).get();
                         // Otherwise, filter out Banned
@@ -313,6 +329,18 @@ function buildSubmit (workflow, sitesToRun) {
     return output;
 }
 
+
+function showStatus(workflow) {
+    $.ajax({
+        url: "/getstatus",
+        data: {"workflow": workflow},
+        success: function (status) {
+            document.getElementById("actionstatus").innerHTML = "Action: " + status.status;
+        }
+    });
+}
+
+
 function makeForm(workflow) {
 
     $.ajax({
@@ -325,15 +353,20 @@ function makeForm(workflow) {
             var form = formDiv.appendChild(document.createElement("form"));
             form.action = "javascript:;";
             form.onsubmit = function () {
-                submission = buildSubmit(workflow, params.sitestorun);
-                if (confirm("Will submit " + JSON.stringify(submission)))
+                submission = buildSubmit(workflow, params.sitestorun, params.allsites);
+                if (confirm("Will submit " + JSON.stringify(submission))) {
                     $.ajax({
                         url: "/submit2",
                         type: "POST",
                         dataType: "json",
                         contentType : 'application/json',
-                        data: JSON.stringify({documents: submission})
+                        data: JSON.stringify({documents: submission}),
+                        success: function () {
+                            showStatus(workflow);
+                            alert('Action Submitted');
+                        }
                     });
+                }
             };
 
             addOptions(form, params);
@@ -361,4 +394,5 @@ function makeForm(workflow) {
 function prepareSubmit (workflow) {
     makeForm(workflow);
     setReasons();
+    showStatus(workflow);
 };
