@@ -1,9 +1,13 @@
+#pylint: skip-file
+
 """
 Module containing and returning information about workflows.
 
 :authors: Daniel Abercrombie <dabercro@mit.edu>
 """
 
+from __future__ import print_function
+
 import os
 import re
 import json
@@ -69,7 +73,7 @@ def cached_json(attribute, timeout=None):
                         with open(file_name, 'r') as cache_file:
                             check_var = json.load(cache_file)
                     except ValueError:
-                        print 'JSON file no good. Deleting %s. Try again later.' % file_name
+                        print('JSON file no good. Deleting %s. Try again later.' % file_name)
                         os.remove(file_name)
 
                 # If still None, call the wrapped function
@@ -129,11 +133,11 @@ def errors_for_workflow(workflow, url='cmsweb.cern.ch'):
     if not result['result']:
         return output
 
-    for step, stepdata in result['result'][0].get(workflow, {}).iteritems():
+    for step, stepdata in result['result'][0].get(workflow, {}).items():
         errors = {}
-        for code, codedata in stepdata.get('jobfailed', {}).iteritems():
+        for code, codedata in stepdata.get('jobfailed', {}).items():
             sites = {}
-            for site, sitedata in codedata.iteritems():
+            for site, sitedata in codedata.items():
                 if sitedata['errorCount']:
                     sites[site] = sitedata['errorCount']
 
@@ -145,7 +149,6 @@ def errors_for_workflow(workflow, url='cmsweb.cern.ch'):
 
     return output
 
-
 def explain_errors(workflow, errorcode):
     """
     Get example errors for a given workflow and errorcode
@@ -204,7 +207,7 @@ class Info(object):
         """
         Reset the cache for this object and clear out the files.
         """
-        print 'Reseting %s' % self
+        print('Reseting %s' % self)
 
         if not os.path.exists(self.bak_dir):
             os.mkdir(self.bak_dir)
@@ -258,13 +261,13 @@ class WorkflowInfo(Info):
                               use_https=True, use_cert=True)
 
             for params in result['result']:
-                for key, item in params.iteritems():
+                for key, item in params.items():
                     if key == self.workflow:
                         return item
 
         except Exception as error:
-            print 'Failed to get from reqmgr', self.workflow
-            print str(error)
+            print('Failed to get from reqmgr', self.workflow)
+            print(str(error))
 
         return None
 
@@ -309,6 +312,60 @@ class WorkflowInfo(Info):
 
         return output
 
+    @cached_json('reqdetail')
+    def _get_reqdetail(self):
+        """
+        Get the request detail from the wmstatsserver
+
+        :returns: The request detail json from the server or cache
+        :rtype: dict
+        """
+
+        reqDetail = {self.workflow : {}}
+        raw =  get_json(self.url,
+                        '/wmstatsserver/data/request/%s' % self.workflow,
+                        use_cert=True)
+
+        result = raw.get('result', [])
+        if not result: return reqDetail
+
+        reqDetail[self.workflow] = result[0].get(self.workflow, {})
+
+        return reqDetail
+
+    def get_failure_rate(self):
+        """
+        Get failure rate if you happen to have a `WorkflowInfo` object
+
+        :returns: workflow's failure rate
+
+        :rtype: float
+        """
+
+        result = self._get_reqdetail()
+
+        frate = 0.
+        wf_agents = result.get(self.workflow, {}).get('AgentJobInfo', {})
+        if not wf_agents:
+            return frate
+
+        nsuccess = 0
+        nfailure = 0
+        for agent, agentdata in wf_agents.items():
+            status = agentdata.get('status', {})
+            if not status: continue
+
+            nsuccess += status.get('success', 0)
+
+            for ftype, num in status.get('failure', {}).items():
+                nfailure += num
+
+        try:
+            frate = float(nfailure)/(nfailure+nsuccess)
+        except ZeroDivisionError:
+            pass
+
+        return frate
 
     def sum_errors(self):
         """
@@ -350,7 +407,7 @@ class WorkflowInfo(Info):
             task = doc['fileset_name']
             # For each task, we have the following keys:
             # sites - a set of sites that the recovery docs say to run on.
-            for replica, info in doc['files'].iteritems():
+            for replica, info in doc['files'].items():
                 # For fake files, just return the site whitelist
                 if replica.startswith('MCFakeFile'):
                     locations = site_white_list
@@ -383,7 +440,10 @@ class WorkflowInfo(Info):
         all_site_list = site_list()
 
         for site in site_set:
-            clean_site = re.sub(r'_(ECHO_)?(Disk|MSS)$', '', site)
+            if site.startswith('T0_') or site.endswith('_MSS') or site.endswith('_Export'):
+                continue
+
+            clean_site = re.sub(r'_(ECHO_)?(Disk)$', '', site)
             if clean_site not in out_list and clean_site and \
                     clean_site in all_site_list:
                 out_list.append(clean_site)
@@ -418,14 +478,14 @@ class WorkflowInfo(Info):
         if self.explanations is None:
             self.explanations = defaultdict(lambda: defaultdict(lambda: []))
             result = self._get_jobdetail()
-            for stepname, stepdata in result['result'][0].get(self.workflow, {}).iteritems():
+            for stepname, stepdata in result['result'][0].get(self.workflow, {}).items():
                 # Get the errors from both 'jobfailed' and 'submitfailed' details
                 for error, site in [(error, site) for status in ['jobfailed', 'submitfailed'] \
                                         for error, site in stepdata.get(status, {}).items()]:
                     if error == '0':
                         continue
 
-                    for sitename, samples in site.iteritems():
+                    for sitename, samples in site.items():
                         for detail in [values for sample in samples['samples']
                                        for errs in sample['errors'].values()
                                        for values in errs]:
@@ -450,6 +510,22 @@ class WorkflowInfo(Info):
 
         return str(self.get_workflow_parameters().get('PrepID', 'NoPrepID'))
 
+    def get_monitoring_info(self):
+        """
+        :returns: the information to send to CMSMONIT
+        :rtype: dict
+        """
+        # Dummy call to get self.explanations filled
+        self.get_explanation(0)
+
+        return {
+            'errors': self.get_errors(True),
+            'prepID': self.get_prep_id(),
+            'params': self.get_workflow_parameters(),
+            'recovery': self.get_recovery_info(),
+            'logs': self.explanations
+            }
+
 
 class PrepIDInfo(Info):
     """
@@ -490,7 +566,7 @@ class PrepIDInfo(Info):
         request = self.get_requests()
 
         return [(workflow, time.mktime(datetime.datetime(*value['RequestDate']).timetuple())) \
-                    for workflow, value in request.iteritems()]
+                    for workflow, value in request.items()]
 
     def get_workflows(self):
         """
